Module events

Module events 

Structs

ComponentUpdate
An inbound update to be applied to the ECS. Produced by Encoder::decode() on the receiving end.
FragmentedEvent
An event representing a fragment of a larger message. Used for MTU stability to prevent packet drops and enable reassembly.
ReplicationEvent
An event representing a change to a single component on a single entity. Produced by WorldState::extract_deltas() on the server.

Enums

NetworkEvent
Events produced by GameTransport::poll_events().
WireEvent
A restricted view of NetworkEvent for over-the-wire transport. Prevents local-only variants (like ClientConnected) from being sent/received.